

#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	word工具集
#
###################################################################  

from SpiritLong_word.word import	open_docx
from SpiritLong_word.word import	save_docx
from SpiritLong_word.word import	insert_paragraphs
from SpiritLong_word.word import	delete_paragraph
from SpiritLong_word.word import	add_paragraphs
from SpiritLong_word.word import	new_paragraph_data
from SpiritLong_word.word import	new_run_data
from SpiritLong_word.word import	add_blank_paragraphs
from SpiritLong_word.word import	add_text_with_style
from SpiritLong_word.word import	replace_text
from SpiritLong_word.word import	append_text
from SpiritLong_word.word import	find_paragraph
from SpiritLong_word.word import	get_styles
from SpiritLong_word.word import	table_remove_row
from SpiritLong_word.word import	table_insert_row
from SpiritLong_word.word import	set_cell_border
from SpiritLong_word.word import	table_cell_fill
from SpiritLong_word.word import	create_table
from SpiritLong_word.word import	merge_cell
from SpiritLong_word.word import	set_table_column_width_and_vertical_center




#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	其他工具集
#
###################################################################  

from SpiritLong_utility.datetime	import	datetime_string_parse
from SpiritLong_utility.datetime	import	input_date
from SpiritLong_utility.math		import	decimal2
from SpiritLong_utility.string		import	is_float
from SpiritLong_utility.files		import	walk_for_files
